<?php

/**
 * This class hook to yasr_filter_existing_schema, get the post meta
 * yasr_schema_additional_fields, and depending of the itemType selected
 * returns the schema info
 *
 * Class YasrRichSnippetAdditionalFields
 */
class YasrRichSnippetAdditionalFields {

    public function addFilters() {
        add_filter('yasr_filter_schema_title',    array($this, 'filter_title'));
        add_filter('yasr_filter_existing_schema', array($this, 'additional_schema'));
    }

    //hook to filter title
    public function filter_title($schema_title) {
        $saved_data = $this->saved_data();

        //if is not empty, overwrite the title with custom itemType name
        if(!empty($saved_data['yasr_schema_title'])) {
            $schema_title = $saved_data['yasr_schema_title'];
        }

        return $schema_title;
    }

    public function additional_schema($rich_snippet) {
        $saved_data = $this->saved_data();

        //avoid undefined
        $more_rich_snippet = array();

        //get the select itemTyper
        $review_choosen = yasr_get_itemType();

        if($review_choosen === 'Product') {
            $more_rich_snippet = $this->itemProduct($saved_data);
        }
        if($review_choosen === 'LocalBusiness') {
            $more_rich_snippet = $this->localBusiness($saved_data);
        }
        if($review_choosen === 'Recipe') {
            $more_rich_snippet = $this->recipe($saved_data);
        }

        if($review_choosen === 'SoftwareApplication') {
            $more_rich_snippet = $this->softwareApplication($saved_data);
        }

        return array_merge($rich_snippet, $more_rich_snippet);

    }

    private function itemProduct($saved_data) {
        $global_identifer_name = $saved_data['yasr_product_global_identifier_select'];

        $rich_snippet['brand']                = $saved_data['yasr_product_brand'];
        $rich_snippet['sku']                  = $saved_data['yasr_product_sku'];
        $rich_snippet[$global_identifer_name] = $saved_data['yasr_product_global_identifier_value'];

        if(!empty($saved_data['yasr_product_price'])) {
            $rich_snippet['offers'] = array(
                '@type'           => 'Offer',
                'price'           => $saved_data['yasr_product_price'],
                'priceCurrency'   => $saved_data['yasr_product_price_currency'],
                'priceValidUntil' => $saved_data['yasr_product_price_valid_until'],
                'availability'    => $saved_data['yasr_product_price_availability'],
                'url'             => $saved_data['yasr_product_price_url'],
            );

        }
        return $rich_snippet;
    }

    private function localBusiness($saved_data) {
        $rich_snippet['address']            = $saved_data['yasr_localbusiness_address'];
        $rich_snippet['priceRange']         = $saved_data['yasr_localbusiness_pricerange'];
        $rich_snippet['telephone']          = $saved_data['yasr_localbusiness_telephone'];

        return $rich_snippet;
    }

    private function recipe($saved_data) {

        $instruction_array_clean = array();
        $ingredient_array        = array();

        if(!empty($saved_data['yasr_recipe_recipeinstructions'])) {
            $instruction_array = explode(PHP_EOL, $saved_data['yasr_recipe_recipeinstructions']);
            $i=0;
            $j=1;
            foreach ($instruction_array as $instrunction) {
                $instruction_array_clean[$i]['@type'] = "HowToStep";
                $instruction_array_clean[$i]["itemListElement"] = array(
                    '@type'    => 'ListItem',
                    'position' => $j,
                    'name'     => $instrunction
                );
                $i++;
                $j++;
            }
        }

        if(!empty($saved_data['yasr_recipe_recipeingredient'])) {
            $ingredient_array = explode(PHP_EOL, $saved_data['yasr_recipe_recipeingredient']);
        }

        if(!empty($saved_data['yasr_recipe_nutrition'])) {
            $rich_snippet['nutrition'] = array(
                "@type"    => "NutritionInformation",
                "calories" => $saved_data['yasr_recipe_nutrition'] . " calories",
            );

        }

        $rich_snippet['author'] = array(
            '@type' => 'Person',
            'name'  => get_the_author()
        );

        $rich_snippet['cookTime']           = $saved_data['yasr_recipe_cooktime'];
        $rich_snippet['description']        = $saved_data['yasr_recipe_description'];
        $rich_snippet['keywords']           = $saved_data['yasr_recipe_keywords'];
        $rich_snippet['prepTime']           = $saved_data['yasr_recipe_preptime'];
        $rich_snippet['recipeCategory']     = $saved_data['yasr_recipe_recipecategory'];
        $rich_snippet['recipeCuisine']      = $saved_data['yasr_recipe_recipecuisine'];
        $rich_snippet['recipeIngredient']   = $ingredient_array;
        $rich_snippet['recipeInstructions'] = $instruction_array_clean;
        $rich_snippet['video']              = $saved_data['yasr_recipe_video'];

        return $rich_snippet;
    }

    private function softwareApplication($saved_data) {

        $rich_snippet['applicationCategory'] = $saved_data['yasr_software_application'];
        $rich_snippet['operatingSystem']     = $saved_data['yasr_software_os'];

        if(!empty($saved_data['yasr_software_price'])) {
            $rich_snippet['offers'] = array(
                '@type'           => 'Offer',
                'price'           => $saved_data['yasr_software_price'],
                'priceCurrency'   => $saved_data['yasr_software_price_currency'],
                'priceValidUntil' => $saved_data['yasr_software_price_valid_until'],
                'availability'    => $saved_data['yasr_software_price_availability'],
                'url'             => $saved_data['yasr_software_price_url'],
            );

        }
        return $rich_snippet;
    }

    private function saved_data() {
        $saved_data = get_post_meta(get_the_ID(), 'yasr_schema_additional_fields', true);
        //avoid undefined
        if(!is_array($saved_data)) {
            $saved_data = array();
        }

        $array_item_type_info = json_decode(YASR_SUPPORTED_SCHEMA_TYPES_ADDITIONAL_FIELDS, true);

        foreach ($array_item_type_info as $item_type) {
            //avoid undefined
            if(!isset($saved_data[$item_type])) {
                $saved_data[$item_type] = '';
            }
        }

        return $saved_data;
    }
}